Learn R Programming

vascr (version 0.1.4)

small_growth.df: Small growth data set for testing

Description

Small growth data set for testing

Usage

small_growth.df

Arguments

Format

A tibble with 346370 rows and 9 variables:

Time

The time at which the measurement was taken (hours)

Unit

The unit the measurement was taken in

Well

The well in which the measurement was taken

Value

The value of the measurement taken

Frequency

The frequency at which data was collected

Experiment

Name of the experiment

Instrument

The instrument data was collected on

SampleID

The numerical ID of the sample

Sample

The name of the treatment applied to the dataset