Learn R Programming

vascr (version 0.1.4)

vascr-package: vascr: Process Biological Impedance Sensing Data

Description

Process complex impedance sensing datasets, including those generated by ECIS, xCELLigence and cellZscope instruments. Data can be imported to a standardised tidy format and then plotted. Support for conducting and plotting the outputs of ANOVA (with appropriate tests of statistical assumptions) and cross-correlation analysis. For data processed using this package see Hucklesby et al. (2020) tools:::Rd_expr_doi("10.3390/bios11050159").

Arguments

Author

Maintainer: James JW Hucklesby james.hucklesby@auckland.ac.nz (ORCID) [copyright holder]

Authors:

See Also