vascr_normalise: Normalize ECIS data to a single time point
Description
This function normalises each unique experiment/well combination to it's value at the specified time. Contains options to do this either by division or subtraction. Can be run twice on the same dataset if both operations are desired.