Learn R Programming

vascr (version 0.1.4)

vascr_resample_time: Resample a vascr dataset

Description

Impedance sensing data is often not collected simultaneously, which creates issues summarising and plotting the data. This function interpolates these data to allow these downstream functions to happen.

Usage

vascr_resample_time(
  data.df,
  npoints = vascr_find_count_timepoints(data.df),
  t_start = min(data.df$Time),
  t_end = max(data.df$Time),
  rate = NULL,
  force_timepoint = NULL,
  include_disc = TRUE
)

Value

An interpolated vascr dataset

Arguments

data.df

The vascr dataset to resample

npoints

Manually specificity the number of points to resample at, default is the same frequency as the input dataset

t_start

Time to start at

t_end

Time to end at

rate

Time between timepoints

force_timepoint

Force a specific timepoint to be part of the resample

include_disc

Add an additional data point either side of a discrepancy. Defaults TRUE

Examples

Run this code
# Automatically re sample, mimicking the input data as closely as possible
vascr_resample_time(growth.df)

# Fully controlled resample with advanced options
vascr_resample_time(growth.df, t_start = 5, t_end = 20, rate = 5, force = c(1,2,3))

Run the code above in your browser using DataLab