Learn R Programming

vascr (version 0.1.4)

vascr_add_vline: Add a vertical line to a vascr line plot

Description

Add a vertical line to a vascr line plot

Usage

vascr_add_vline(plot, times.df)

Value

A labeled vascr plot

Arguments

plot

The vascr plot to receive a vertical line (or lines)

times.df

A tibble containing "time", "color" and "label" columns to specify the addition of lines

Examples

Run this code
plot1_data = growth.df %>% vascr_subset(unit = "R", frequency = "4000")
plot1 = plot1_data %>% vascr_summarise("summary") %>% vascr_plot_line()

times.df = tribble(~time, ~label, ~colour, 100, "Test Point", "orange")
vascr_add_vline(plot1, times.df)

times.df = tribble(~time, ~label, 100, "ZTest Point", 150, "Test Point 2")
vascr_add_vline(plot1, times.df)

Run the code above in your browser using DataLab