Learn R Programming

vascr (version 0.1.4)

vascr_combine: Combine ECIS data frames end to end

Description

This function will combine ECIS data sets end to end. Preferential to use over a simple rbind command as it runs additional checks to ensure that data points are correctly generated

Usage

vascr_combine(..., resample = FALSE)

Value

A single data frame containing all the data imported, automatically incremented by experiment

Arguments

...

List of data frames to be combined

resample

Automatically try and re sample the data set. Default is FALSE

Examples

Run this code
#Make three fake experiments worth of data
experiment1.df = vascr_subset(growth.df, experiment = "1")
experiment2.df = vascr_subset(growth.df, experiment = "2")
experiment3.df = vascr_subset(growth.df, experiment = "3")

data = vascr_combine(experiment1.df, experiment2.df, experiment3.df)
head(data)


Run the code above in your browser using DataLab