powered by
Print out the characteristics of the vascr data frame
vascr_find_metadata(data.df)
prints out the parameters of the dataframe in question
the vascr data frame to interrogate
vascr_find_metadata(growth.df)
Run the code above in your browser using DataLab